#
# spec file for package tiled
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tiled
Version:        0.18.2
Release:        1.4
Summary:        A tilemap editor
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Url:            http://www.mapeditor.org
Source:         https://github.com/bjorn/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  shared-mime-info
BuildRequires:  zlib-devel
Recommends:     tmxtools
Provides:       tiled-qt

%description
Tiled is a general purpose tile map editor. It is built to work with
varying game engines, whether your game is an RPG, platformer or
Breakout clone. Tiled is written in C++, using the Qt application
framework.

%package -n tmxtools
Summary:        Commandline Tools for Tiled MapEditor
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other

%description -n tmxtools
This package contains tmxviewer, a simple application to view Tiled maps
and tmxrasterizer which is also a command line tool.

%package -n libtiled1
Summary:        Library for Tiled MapEditor
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++

%description -n libtiled1
This package contains libtiled a library for the Tiled map editor.

%prep
%setup -q
# Remove copy of zlib
rm -rf src/zlib

%build
qmake-qt5 -r PREFIX=%{_prefix} LIBDIR=%{_libdir} RPATH=no USE_FHS_PLUGIN_PATH=yes

make %{?_smp_mflags}

%install
make install INSTALL_ROOT=%{buildroot}

# Clean build artefacts
find -name ".uic" -or -name ".moc" -or -name ".rcc" | xargs rm -rf

# locale files
%find_lang %{name} --with-qt

# Removed development file (this version does not install headers anyway)
rm %{buildroot}%{_libdir}/lib%{name}.so

# Remove duplicates
%fdupes %{buildroot}%{_datadir}

# Install software gallery metadata
install -Dm0644 tiled.appdata.xml %{buildroot}%{_datadir}/appdata/tiled.appdata.xml

%post -n libtiled1 -p /sbin/ldconfig
%postun -n libtiled1 -p /sbin/ldconfig
%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS NEWS.md README.md COPYING LICENSE.GPL LICENSE.BSD
%{_bindir}/%{name}
%{_bindir}/terraingenerator
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/mimetypes/application-x-%{name}.*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/%{name}.xml
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/translations
%{_libdir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files -n libtiled1
%defattr(-,root,root)
%doc LICENSE.BSD
%{_libdir}/lib%{name}.so.*

%files -n tmxtools
%defattr(-,root,root)
%doc LICENSE.BSD
%{_bindir}/automappingconverter
%{_bindir}/tmxrasterizer
%{_bindir}/tmxviewer
%{_mandir}/man1/tmxviewer.1%{ext_man}
%{_mandir}/man1/tmxrasterizer.1%{ext_man}
%{_mandir}/man1/automappingconverter.1%{ext_man}
%dir %{_datadir}/thumbnailers/
%{_datadir}/thumbnailers/tiled.thumbnailer

%changelog
* Tue Mar  7 2017 mvetter@suse.com
- Update to 0.18.2:
  * Fixed crash when deleting multiple selected objects
  * Fixed crash when moving multiple selected objects to another object layer
  * Fixed updating of values displayed in Objects and Layers views
  * GmxPlugin: Added support for image collection tilesets
  * Object Types Editor: Improved behavior when adding new types
  * Linux: Fixed shipping of image format plugins in AppImage releases
* Thu Feb  2 2017 jengelh@inai.de
- Trim filler words from description
* Fri Jan 27 2017 mvetter@suse.com
- Update to 0.18.1:
  * Fixed terrain brush for isometric staggered maps (by Clyde)
  * Fixed crash when resizing map causes objects to get removed
  * Fixed crash when duplicating an object layer
  * Fixed position of image layer after Resize or Offset Map
  * Fixed the quality of the minimap on HiDpi displays
  * Fixed Alt-drag behavior to not override resize handles
  * When adding a new layer, insert it above the current one
  * GmxPlugin: Fixed positioning for non-tile objects and support scaling
  * GmxPlugin: Export tile objects without a type as tiles
  * GmxPlugin: Support horizontal and vertical flipping
  * Updated Chinese translation (by Clyde)
* Tue Dec 20 2016 mvetter@suse.com
- Fix plugin detection:
  We need USE_FHS_PLUGIN_PATH=yes so tiled finds the plugins and
  doesn't look relative to the executables path.
  Without this exporting to lua, json etc never worked.
* Tue Dec 20 2016 mvetter@suse.com
- Update to version 0.18.0:
  * Added Layer via Copy/Cut actions
  * Added support for Paste in Place action for tile layers
  * Added context menu to change custom property type (by Dmitry Hrabrov)
  * Added support for higher precision for custom floating point properties
  * Added %%mappath variable to commands (by Jack Roper)
  * Added snapping to pixels (by Mamed Ibrahimov)
  * Added right-click to clear the tile selection
  * Added a context menu action to reset the size of tile objects
  * Added exporter for Game Maker Studio room files (by Jones Blunt)
  * Added Move Up/Down buttons to Objects view (by iskolbin)
  * Added pixel coordinates to status bar for object tools (by iskolbin)
  * Added Sticker Knight platformer example (by Ponywolf)
  * tmxrasterizer: Added --size argument and support local file URLs
  * tmxrasterizer: Use smooth pixmap transform by default
  * Linux: Register tmxrasterizer as thumbnail generator for TMX files
  * Allow scrolling past map edges with mouse wheel
  * Enabled HiDpi scaling and improved the quality of some icons
  * Reversed the order of the objects in the Objects view
  * JSON plugin: Added Node.js support to the JavaScript export
  * Updated TMX schema definition (by assofohdz)
  * Fixed unfinished objects getting saved
  * Fixed OpenGL rendering mode when application is scaled (HiDpi screens)
  * Fixed Remove and Rename actions for predefined properties
  * Windows: Fixed console output
  * libtiled-java: Use Maven, deploy to OSSRH and code updates (by Mike Thomas)
  * libtiled-java: Added a basic isometric renderer (by Mike Thomas)
  * Updated Brazilian Portuguese, Chinese, Czech, Dutch, Hebrew, Norwegian Bokmål and Spanish translations
  See: http://discourse.mapeditor.org/t/tiled-0-18-0-released/1897
- Add tiled.thumbnailer
* Wed Oct 12 2016 mailaender@opensuse.org
- Add icon/desktop/mime macros
- Install appdata for https://en.opensuse.org/openSUSE:AppStore
- Update to version 0.17.0
  * Added a platform-independent theme, which can be dark (#786)
  * Added Paste in Place action for objects (#1257)
  * Added custom property type 'color' (#1275)
  * Added custom property type 'file' (#1278)
  * Added option for removing invisible objects in resize dialog (#1032, by Mamed Ibrahimov)
  * Added support for editing multi-line string properties (#205)
  * Added %%layername and %%objectid to available command variables
  * Added support for scrolling in tileset view with middle mouse button (#1050, with Will Luongo)
  * Added a rectangle erase mode to the eraser (#1297)
  * Added export to Defold .tilemap files (#1316, by Nikita Razdobreev)
  * Added simple full screen mode
  * Added "Copy File Path" and "Open Containing Folder" actions to tab context menu
  * Added warning when saving with the wrong file extension
  * Added color picker for setting transparent color of a tileset (#1173, by Ava Brumfield)
  * Various object selection tool improvements
  * Allow creating rectangle/ellipse objects in any direction (#1300)
  * Enabled nested views and grouped dragging for stacked views (#1291)
  * Fixed updating object drag cursor when exiting resize handles (#1277)
  * Fixed tile animations to stay in sync when changing them (#1288)
  * Fixed preservation of tile meta-data when tileset width is changed (#1315)
  * Updated Bulgarian, Dutch, German, Norwegian Bokmål, Russian, Spanish and Turkish translations
  * JSON plugin: Fixed loading of custom properties on terrains
  * Lua plugin: Fixed missing export of object layer drawing order
  * Fixed tile index adjustment when tileset image changes width
  * Fixed --export-map [format] option
  * Fixed shortcuts for some tools when language is set to Dutch
  * Fixed a painting related bug affecting the top edge after AutoMapping
* Fri May 13 2016 rpm@fthiessen.de
- Update to version 0.16.1
  * Bugfix release, some crashed are fixed.
* Mon May  2 2016 rpm@fthiessen.de
- Update to version 0.16.0
- Minor spec cleanup
* Wed Jun 17 2015 roman@priesol.net
- update to version 0.12.3
* Sun Jan  4 2015 bemyak@gmail.com
- update to version 0.10.2
* Wed Nov 13 2013 mailaender@opensuse.org
- update to version 0.9.1
- spec and file cleanup
- removed desktop file and icon (now included)
- https://en.opensuse.org/SourceUrls
- separated GUI tool, library and cli tools
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- fixed qt4->qt
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- Removed conflict line
* Fri Feb  1 2013 ablu.erikschilling@googlemail.com
- Added conflict line
* Mon Jan 28 2013 ablu.erikschilling@googlemail.com
- Added obsolete line
* Sat Jan 12 2013 ablu.erikschilling@googlemail.com
- New upstream release 0.9.0
- Dropped now obsolete patches and files
* Mon Sep  3 2012 ablu.erikschilling@googlemail.com
- Added note about which parts are licensed with which license.
- Made sure that the copy of zlib inside of the source is removed.
- Fixed handling of locales (using %%%%find_lang).
- Avoided plain asterisks in %%%%files.
- Made description clear about containing the tmxviewer.
* Sun Sep  2 2012 ablu.erikschilling@googlemail.com
- First version for official fedora repos.
* Fri May 11 2012 ablu.erikschilling@googlemail.com
- Copied package to obs, fixed problems occurring there.
